@@ -50,11 +50,10 @@ class LMDBBackend:
 
         with self.env.begin(write=False) as txn:
             self.length = pa.deserialize(txn.get(b'__len__'))
-            self.keys = pa.deserialize(txn.get(b'__keys__'))
 
     def retreive(self, key: str, decoder: str = 'raw'):
         with self.env.begin(write=False) as txn:
-            byteflow = txn.get(key)
+            byteflow = txn.get(u'{}'.format(key).encode('ascii'))
         unpacked = pa.deserialize(byteflow)
 
         if(decoder == 'image_color'):
